max_study_registry_wait

Function max_study_registry_wait 

pub fn max_study_registry_wait(phase: CreditRegistrationPhase) -> Duration
The longest one iteration of phase may wait on the study registry before its calls time out.